<?php $TRANSLATIONS = array(
"Help" => "Ajuda",
"Personal" => "Personal",
"Settings" => "Configuracion",
"Users" => "Usancièrs",
"Apps" => "Apps",
"Admin" => "Admin",
"ZIP download is turned off." => "Avalcargar los ZIP es inactiu.",
"Files need to be downloaded one by one." => "Los fichièrs devan èsser avalcargats un per un.",
"Back to Files" => "Torna cap als fichièrs",
"Authentication error" => "Error d'autentificacion",
"Files" => "Fichièrs",
"seconds ago" => "segonda a",
"1 minute ago" => "1 minuta a",
"%d minutes ago" => "%d minutas a",
"today" => "uèi",
"yesterday" => "ièr",
"%d days ago" => "%d jorns a",
"last month" => "mes passat",
"last year" => "an passat",
"years ago" => "ans a",
"up to date" => "a jorn",
"updates check is disabled" => "la verificacion de mesa a jorn es inactiva"
);
